==> haskell-stream-0.4.7.2-128-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-stream.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 Stream
version:              0.4.7.2
visibility:           public
id:                   Stream-0.4.7.2-5KYedP6GvCyVV6NAYEV34
key:                  Stream-0.4.7.2-5KYedP6GvCyVV6NAYEV34
license:              BSD-3-Clause
maintainer:           Wouter Swierstra <wouter.swierstra@gmail.com>
author:
    Wouter Swierstra <wouter.swierstra@gmail.com>
    Bas van Dijk <v.dijk.bas@gmail.com>

stability:            experimental
synopsis:             A library for manipulating infinite lists.
description:
    This package implements functions, analogous
    to those from Data.List, to create and manipulate
    infinite lists: @data Stream a = Cons a (Stream a)@.
    It provides alternative definitions for those
    Prelude functions that make sense for such streams.
    Note that this package has (almost)
    nothing to do with the work on /Stream Fusion/ by
    Duncan Coutts, Roman Leshchinskiy, and Don Stewart.

category:             Data
abi:                  eb0db8dd5ad4e8641aa46ac3b204f5d7
exposed:              True
exposed-modules:      Data.Stream
import-dirs:          /usr/lib/ghc-9.2.8/site-local/Stream-0.4.7.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/Stream-0.4.7.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stream
hs-libraries:         HSStream-0.4.7.2-5KYedP6GvCyVV6NAYEV34
depends:
    QuickCheck-2.14.3-AB831W8sF74KL3cz7DxP1X base-4.16.4.0
    lazysmallcheck-0.6-7a6d9xZ9chG3eyNv7XLsB

haddock-interfaces:   /usr/share/doc/haskell-stream/html/Stream.haddock
haddock-html:         /usr/share/doc/haskell-stream/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stream-0.4.7.2-156.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-stream.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Stream
version:              0.4.7.2
visibility:           public
id:                   Stream-0.4.7.2-KVDx1wVckQXKi3i6QBn3KS
key:                  Stream-0.4.7.2-KVDx1wVckQXKi3i6QBn3KS
license:              BSD-3-Clause
maintainer:           Wouter Swierstra <wouter.swierstra@gmail.com>
author:
    Wouter Swierstra <wouter.swierstra@gmail.com>
    Bas van Dijk <v.dijk.bas@gmail.com>

stability:            experimental
synopsis:             A library for manipulating infinite lists.
description:
    This package implements functions, analogous
    to those from Data.List, to create and manipulate
    infinite lists: @data Stream a = Cons a (Stream a)@.
    It provides alternative definitions for those
    Prelude functions that make sense for such streams.
    Note that this package has (almost)
    nothing to do with the work on /Stream Fusion/ by
    Duncan Coutts, Roman Leshchinskiy, and Don Stewart.

category:             Data
abi:                  4675b44ffc7b11f426533e2f2a022e7d
exposed:              True
exposed-modules:      Data.Stream
import-dirs:          /usr/lib/ghc-9.4.8/site-local/Stream-0.4.7.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/Stream-0.4.7.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/Stream-0.4.7.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stream
hs-libraries:         HSStream-0.4.7.2-KVDx1wVckQXKi3i6QBn3KS
depends:
    QuickCheck-2.14.3-Gpw9UoHUxB71c0Trj8n39O base-4.17.2.1
    lazysmallcheck-0.6-AmDuPsPRVQ34kdXMu8rwYU

haddock-interfaces:   /usr/share/doc/haskell-stream/html/Stream.haddock
haddock-html:         /usr/share/doc/haskell-stream/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
